summaryrefslogtreecommitdiff
path: root/muse2/muse/steprec.cpp
diff options
context:
space:
mode:
authorTim E. Real <termtech@rogers.com>2011-08-05 08:28:29 +0000
committerTim E. Real <termtech@rogers.com>2011-08-05 08:28:29 +0000
commite2084952744efe4c6cf9137ba0c544c115064d5f (patch)
treec40c1a49039d86648075970866a20764eae07fa8 /muse2/muse/steprec.cpp
parent0dbef158d3bf5a96bbd2b4432bcc23223783d3d4 (diff)
Parts having hidden events now drawn using 'jagged' ends and special white edges.
Improved border drawing guaranteed to show L/R touching part borders. TODO: Top and bottom borders. Muted parts now show names and events. Filled with a special brush pattern for easy recognition. Huge changes to PartCanvas::drawItem(). And to all View::XmapXXX methods for better accuracy. Changed bool Part::hasHiddenNotes() to int Part::hasHiddenEvents(). Added int Part::cachedHasHiddenEvents().
Diffstat (limited to 'muse2/muse/steprec.cpp')
-rw-r--r--muse2/muse/steprec.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/muse2/muse/steprec.cpp b/muse2/muse/steprec.cpp
index c1fc23b1..45af3930 100644
--- a/muse2/muse/steprec.cpp
+++ b/muse2/muse/steprec.cpp
@@ -77,7 +77,7 @@ void StepRec::record(Part* part, int pitch, int len, int step, int velo, bool ct
{
// if we already entered the note, delete it
// if we would find a note after part->lenTick(), the above "if"
// avoids this. this has to be avoided because then part->hasHiddenNotes() is true
// which results in forbidding any action beyond its end
EventRange range = events->equal_range(tick - part->tick());
for (iEvent i = range.first; i != range.second; ++i)
@@ -173,7 +173,7 @@ void StepRec::record(Part* part, int pitch, int len, int step, int velo, bool ct
}
steprec_record_foot:
- if (!((lasttick > part->lenTick()) && part->hasHiddenNotes())) // allowed?
+ if (!((lasttick > part->lenTick()) && part->hasHiddenEvents())) // allowed?
{
if (lasttick > part->lenTick()) // we have to expand the part?
schedule_resize_all_same_len_clone_parts(part, lasttick, operations);
@@ -77,7 +77,7 @@ void StepRec::record(Part* part, int pitch, int len, int step, int velo, bool ct
// if we already entered the note, delete it
// if we would find a note after part->lenTick(), the above "if"
- // avoids this. this has to be avoided because then part->hasHiddenNotes() is true
+ // avoids this. this has to be avoided because then part->hasHiddenEvents() is true
// which results in forbidding any action beyond its end
EventRange range = events->equal_range(tick - part->tick());